@@ -1,5 +1,5 @@
 /* Definitions for Windows
-Copyright (C) 1996-2013 Free Software Foundation, Inc.
+Copyright (C) 1996-2016 Free Software Foundation, Inc.
 This file is part of GNU Make.
 
 GNU Make is free software; you can redistribute it and/or modify it under the
@@ -19,11 +19,11 @@ this program.  If not, see <http://www.gnu.org/licenses/>.  */
 
 typedef int bool_t;
 
-#define E_SCALL		101
-#define E_IO		102
-#define E_NO_MEM	103
-#define E_FORK		104
+#define E_SCALL         101
+#define E_IO            102
+#define E_NO_MEM        103
+#define E_FORK          104
 
-extern bool_t arr2envblk(char **arr, char **envblk_out);
+extern bool_t arr2envblk(char **arr, char **envblk_out, int *envsize_needed);
 
 #endif
